@@ -170,7 +170,6 @@ scrabble_points <- function(lang) {
 #' grepl_letters(x, "c")
 #' @export
 grepl_letters <- function(x, pattern, blank = "_") {
-
   # When no black tile, use simple grepl function
   if (!grepl(blank, pattern)) {
     return(grepl(pattern, x, fixed = TRUE))
@@ -279,7 +278,6 @@ scrabble_words <- function(tiles = "",
                            words = NULL,
                            quiet = FALSE,
                            print = TRUE) {
-
   ### POINTS
 
   tiles <- paste(tiles, collapse = "")
@@ -303,7 +301,7 @@ scrabble_words <- function(tiles = "",
   tiles <- .add_letters(force_end, tiles)
   tiles <- .add_letters(force_str, tiles)
   # Force N letters (complete free)
-  if (force_n > 0 & length(tiles) < force_n) {
+  if (force_n > 0 && length(tiles) < force_n) {
     tiles <- c(tiles, rep("_", times = (force_n - length(tiles))))
   }
   ntiles <- as.integer(length(tiles))
@@ -357,7 +355,7 @@ scrabble_words <- function(tiles = "",
     these <- str_split(pos_tiles, "\\|")[i][[1]]
     if (!any(these %in% letters)) next
     located <- stringr::str_locate_all(words, pos_tiles[i])
-    these <- !sapply(located, function(x) sum(x[,1] == i) > 0)
+    these <- !unlist(lapply(located, function(x) sum(x[, 1] == i) > 0))
     words <- words[these]
     .temp_print(length(words))
   }
@@ -373,7 +371,7 @@ scrabble_words <- function(tiles = "",
 }
 
 .temp_print <- function(x, print = TRUE, last = FALSE) {
- if (print) if (!last) formatColoured(paste(x, "> ")) else formatColoured(paste(x, "\n"))
+  if (print) if (!last) formatColoured(paste(x, "> ")) else formatColoured(paste(x, "\n"))
 }
 
 # Tile used, tile that must be skipped on next iterations
@@ -396,9 +394,12 @@ scrabble_words <- function(tiles = "",
 }
 
 .reverse <- function(words) {
-  splits <- sapply(words, function(x) strsplit(x, ""))
-  reversed <- lapply(splits, rev)
-  words <- as.vector(unlist(lapply(reversed, function(x) paste(x, collapse = ""))))
+  original_class <- class(words)
+  words <- as.character(words)
+  splits <- lapply(words, function(x) strsplit(x, ""))
+  reversed <- lapply(splits, function(x) rev(x[[1]]))
+  words <- unlist(lapply(reversed, function(x) paste(x, collapse = "")))
+  class(words) <- original_class
   return(words)
 }
 
